@@ -1,5 +1,6 @@
-#!/usr/bin/env python3
 import asyncio
+import logging
+import time
 from collections import defaultdict
 from typing import Any, Callable, Optional, Set, Tuple
 
@@ -17,13 +18,19 @@ async def loop():
     while True:
         visited: Set[Tuple[int, str]] = set()
         visited_views: Set[HTMLBaseComponent] = set()
+        t = time.time()
         for link in active_links:
             (source_obj, source_name, target_obj, target_name, transform) = link
             value = transform(getattr(source_obj, source_name))
             if getattr(target_obj, target_name) != value:
                 setattr(target_obj, target_name, value)
                 propagate(target_obj, target_name, visited, visited_views)
+        if time.time() - t > 0.01:
+            logging.warning(f'binding propagation for {len(active_links)} active links took {time.time() - t:.3f} s')
+        t = time.time()
         update_views(visited_views)
+        if time.time() - t > 0.01:
+            logging.warning(f'binding update for {len(visited_views)} visited views took {time.time() - t:.3f} s')
         await asyncio.sleep(config.binding_refresh_interval)
 
 
@@ -85,7 +92,10 @@ class BindableProperty:
         return getattr(owner, '_' + self.name)
 
     def __set__(self, owner: Any, value: Any):
-        value_changed = getattr(owner, '_' + self.name, value) != value
+        has_attribute = hasattr(owner, '_' + self.name)
+        value_changed = has_attribute and getattr(owner, '_' + self.name) != value
+        if has_attribute and not value_changed:
+            return
         setattr(owner, '_' + self.name, value)
         bindable_properties[(id(owner), self.name)] = owner
         update_views(propagate(owner, self.name))
