@@ -17,6 +17,8 @@ class Group(Element):
 
     def __exit__(self, *_):
         view_stack.pop()
+        if len(view_stack) <= 1:
+            self.update()  # NOTE: update when we are back on top of the stack (only the first page is in view stack)
 
     def tight(self) -> Group:
         return self.classes(replace='').style(replace='')
@@ -58,3 +60,4 @@ class Group(Element):
                 del bindable_properties[(obj_id, name)]
 
         self.view.delete_components()
+        self.update()
