@@ -1,13 +1,17 @@
 from __future__ import annotations
-from justpy import WebPage
-from typing import Any, Callable, Dict, List, Optional
+
 import traceback
+from typing import Any, Callable, Dict, List, Optional
+
+from justpy import WebPage
+
 from ..events import MouseEventArguments, handle_event
 from .custom_view import CustomView
 from .element import Element
 
 CustomView.use(__file__)
 
+
 class InteractiveImageView(CustomView):
 
     def __init__(self, source: str, on_mouse: Callable, events: List[str], cross: bool):
@@ -24,9 +28,11 @@ class InteractiveImageView(CustomView):
         page_sockets = [s for page_id in self.pages for s in WebPage.sockets.get(page_id, {}).values()]
         self.sockets = [s for s in self.sockets if s in page_sockets]
 
+
 class InteractiveImage(Element):
 
-    def __init__(self, source: str, *, on_mouse: Optional[Callable] = None, events: List[str] = ['click'], cross: bool = False):
+    def __init__(self, source: str, *,
+                 on_mouse: Optional[Callable] = None, events: List[str] = ['click'], cross: bool = False):
         """Interactive Image
 
         Create an image with an SVG overlay that handles mouse events and yields image coordinates.
@@ -39,9 +45,9 @@ class InteractiveImage(Element):
         self.mouse_handler = on_mouse
         super().__init__(InteractiveImageView(source, self.handle_mouse, events, cross))
 
-    def handle_mouse(self, msg: Dict[str, Any]):
+    def handle_mouse(self, msg: Dict[str, Any]) -> Optional[bool]:
         if self.mouse_handler is None:
-            return
+            return False
         try:
             arguments = MouseEventArguments(
                 sender=self,
@@ -50,7 +56,7 @@ class InteractiveImage(Element):
                 image_x=msg.get('image_x'),
                 image_y=msg.get('image_y'),
             )
-            handle_event(self.mouse_handler, arguments)
+            return handle_event(self.mouse_handler, arguments)
         except:
             traceback.print_exc()
 
