@@ -11,8 +11,8 @@ class Switch(BoolElement):
         """Switch Element
 
         :param text: the label to display next to the switch
-        :param value: whether it should be active initally (default: `False`)
-        :param on_click: callback which is invoked when state is changed by the user
+        :param value: whether it should be active initially (default: `False`)
+        :param on_change: callback which is invoked when state is changed by the user
         """
         view = jp.QToggle(text=text, input=self.handle_change, temp=False)
 
