@@ -26,6 +26,8 @@ class Tree(Element):
 
         def process_event(view, event) -> Optional[bool]:
             arguments = ValueChangeEventArguments(sender=self, socket=event.get('websocket'), value=event.get('value'))
-            return handle_event(on_select, arguments, update=self.parent_view)
+            return handle_event(on_select, arguments)
 
         view.on('update:selected', process_event)
+        view.on('update:expanded', lambda *_: self.update())
+        view.on('update:ticked', lambda *_: self.update())
