@@ -2,7 +2,7 @@ import inspect
 import os
 import sys
 import webbrowser
-from typing import Callable, Optional
+from typing import Optional
 
 import uvicorn
 
@@ -34,14 +34,17 @@ def run(self, *,
         dark: Optional[bool] = False,
         reload: bool = True,
         show: bool = True,
-        on_connect: Optional[Callable] = None,
         uvicorn_logging_level: str = 'warning',
         uvicorn_reload_dirs: str = '.',
         uvicorn_reload_includes: str = '*.py',
         uvicorn_reload_excludes: str = '.*, .py[cod], .sw.*, ~*',
         main_page_classes: str = 'q-ma-md column items-start',
         binding_refresh_interval: float = 0.1,
+        exclude: str = '',
         ):
+    if globals.config.interactive:
+        print('Error: Unexpected ui.run() in interactive mode.', flush=True)
+        sys.exit()
 
     if globals.config.interactive or reload == False:  # NOTE: if reload == True we already started uvicorn above
         if show:
